@@ -1,4 +1,4 @@
-from botty import CommandHandler, CompositeHandler, StartHandler, app
+from botty import CommandHandler, CompositeHandler, QueryHandler, StartHandler, app
 
 
 class TestHandler(CommandHandler):
@@ -14,6 +14,7 @@ handler = CompositeHandler(
     StartHandler("Hello"),
     CommandHandler("help", "Help"),
     TestHandler(),
+    QueryHandler(reply_text="?"),
 )
 
 app.run(handler)
